# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

Summary:	Tools to test taintedness
Name:		perl-Test-Taint
Version:	1.08
Release:	14.%{__distinit}%{__distvers}
License:	GPL-1.0-or-later OR Artistic-1.0-Perl
URL:		https://metacpan.org/release/Test-Taint
Source0:	https://cpan.metacpan.org/modules/by-module/Test/Test-Taint-%{version}.tar.gz
# Module Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	gcc
BuildRequires:	make
BuildRequires:	perl-devel
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(ExtUtils::MakeMaker)
# Module Runtime
BuildRequires:	perl(base)
BuildRequires:	perl(DynaLoader)
BuildRequires:	perl(overload)
BuildRequires:	perl(Scalar::Util)
BuildRequires:	perl(strict)
BuildRequires:	perl(Test::Builder)
BuildRequires:	perl(vars)
BuildRequires:	perl(warnings)
# Test Suite
BuildRequires:	perl(constant)
BuildRequires:	perl(Test::More)
BuildRequires:	perl(Tie::Array)
BuildRequires:	perl(Tie::Hash)
BuildRequires:	perl(Tie::Scalar)
BuildRequires:	perl(Tie::StdArray)
BuildRequires:	perl(Tie::StdHash)
BuildRequires:	perl(Tie::StdScalar)
# Optional Tests
BuildRequires:	perl(Test::Pod) >= 1.14
BuildRequires:	perl(Test::Pod::Coverage) >= 1.04
# Dependencies
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%endif

# Don't "provide" private Perl libs
%{?perl_default_filter}

%description
Tainted data is data that comes from an unsafe source, such as the command
line, or, in the case of web apps, any GET or POST transactions. Read the 
perlsec man page for details on why tainted data is bad, and how to untaint
the data.

When you're writing unit tests for code that deals with tainted data, you'll
want to have a way to provide tainted data for your routines to handle, and 
easy ways to check and report on the taintedness of your data, in standard 
Test::More style.

%prep
%setup -q -n Test-Taint-%{version}

%build
perl Makefile.PL INSTALLDIRS=vendor OPTIMIZE="%{optflags}"
make %{?_smp_mflags}

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
find %{buildroot} -type f -name '*.bs' -empty -delete
%{_fixperms} -c %{buildroot}

%check
make test

%files
%doc Changes
%{perl_vendorarch}/Test/
%{perl_vendorarch}/auto/Test/
%{_mandir}/man3/Test::Taint.3*

%changelog
* Wed Jul 12 2023 Paul Howarth <paul@city-fan.org> - 1.08-14
- Perl 5.38 rebuild

* Mon Jun 26 2023 Paul Howarth <paul@city-fan.org> - 1.08-13
- Use SPDX-format license tag

* Wed Jun  1 2022 Paul Howarth <paul@city-fan.org> - 1.08-10
- Perl 5.36 rebuild

* Sat May 22 2021 Paul Howarth <paul@city-fan.org> - 1.08-7
- Perl 5.34 rebuild

* Fri Jun 26 2020 Paul Howarth <paul@city-fan.org> - 1.08-4
- Perl 5.32 rebuild

* Thu Jun 13 2019 Paul Howarth <paul@city-fan.org> - 1.08-1
- Update to 1.08
  - Fixed intermittent failures in the test suite (CPAN RT#119897)

* Mon Jun  3 2019 Paul Howarth <paul@city-fan.org> - 1.06-23
- Perl 5.30 rebuild

* Thu Jun 28 2018 Paul Howarth <paul@city-fan.org> - 1.06-20
- Perl 5.28 rebuild

* Thu Mar 22 2018 Paul Howarth <paul@city-fan.org> - 1.06-19
- BR: perl-generators unconditionally
- BR: perl-interpreter rather than perl

* Sun Jun 11 2017 Paul Howarth <paul@city-fan.org> - 1.06-16
- Test taintedness on $^X instead of environment variables (#1413022,
  CPAN RT#119897)
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section
  - BR: perl-devel unconditionally

* Thu Oct  6 2016 Paul Howarth <paul@city-fan.org> - 1.06-13
- Classify buildreqs by usage
- Simplify find commands using -empty and -delete

* Mon Sep  1 2014 Paul Howarth <paul@city-fan.org> - 1.06-8
- Drop %%defattr, redundant since rpm 4.4

* Wed Jul 17 2013 Paul Howarth <paul@city-fan.org> - 1.06-3
- Perl 5.18 rebuild

* Sat Oct 20 2012 Paul Howarth <paul@city-fan.org> - 1.06-1
- Update to 1.06
  - tainted() now localizes $SIG{__DIE__} before performing the taint check; if
    the calling program has its own $SIG{__DIE__}, we don't want to use it
    (CPAN RT#23507)
  - Checks for undef before opening files when trying to create some taint
    (CPAN RT#51246)

* Sat Jun 30 2012 Paul Howarth <paul@city-fan.org> - 1.04-17
- BR: perl(base), perl(constant), perl(Scalar::Util), perl(Test::Builder) and
  perl(Test::More)
- Don't need to remove empty directories from the buildroot
- Drop support for old distributions prior to FC-3:
  - Don't need to define %%{perl_vendorarch}
  - Use DESTDIR rather than PERL_INSTALL_ROOT
  - Use %%{_fixperms} macro rather than our own chmod incantation

* Thu Jul  7 2011 Paul Howarth <paul@city-fan.org> - 1.04-14
- Rebuild for perl 5.14.1 in Rawhide
- Nobody else likes macros for commands
- Fix dist tag for CentOS 6 and Scientific Linux

* Thu Jun 24 2010 Paul Howarth <paul@city-fan.org> - 1.04-13
- Rebuild for perl 5.12.1 in Rawhide

* Fri May 28 2010 Paul Howarth <paul@city-fan.org> - 1.04-12
- Fix dist tag for RHEL-6 Beta

* Wed Jan 20 2010 Paul Howarth <paul@city-fan.org> - 1.04-11
- Import from Fedora

* Fri Dec  4 2009 Stepan Kasal <skasal@redhat.com> - 1.04-10
- Rebuild against perl 5.10.1

* Sun Jul 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.04-9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Thu Feb 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.04-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Wed Feb 27 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 1.04-7
- Rebuild for perl 5.10 (again)

* Sun Feb 10 2008 Ralf Corsépius <rc040203@freenet.de> - 1.04-6
- Rebuild for gcc43

* Mon Jan 14 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 1.04-5
- Rebuild for new perl

* Fri Aug 17 2007 Ralf Corsépius <rc040203@freenet.de> - 1.04-4
- Reflect perl-package split
- Update license tag

* Tue Sep 05 2006 Ralf Corsépius <rc040203@freenet.de> - 1.04-3
- Mass rebuild

* Mon Feb 20 2006 Ralf Corsepius <rc040203@freenet.de> - 1.04-2
- Rebuild

* Wed Aug 10 2005 Ralf Corsepius <ralf@links2linux.de> - 1.04-1
- FE submission

* Sun Mar 20 2005 Ralf Corsepius <ralf@links2linux.de> - 1.04-0.pm.2
- Initial version
